@@ -1,22 +1,3 @@
-#' @title
-#' Alternative to readLines that is faster
-#' @description
-#' This alternative is from \url{https://gist.github.com/hadley/6353939}
-#'
-#' @param path Path to text file to read.
-#' @return
-#' Similar to \code{readLines}. It may not return identical results.
-#'
-#' @export
-#' @examples
-#' readLinesRcpp(system.file(package = "reproducible", "DESCRIPTION"))
-#' @rdname readLinesRcpp
-readLinesRcpp <- function(path) {
-  Sys.setlocale(locale = "C") # required to deal with non English characters in Author names
-  on.exit(Sys.setlocale(locale = ""))
-  strsplit(readLinesRcppInternal(path), split = "[{\r}]*\n")[[1]]
-}
-
 .pkgSnapshot <- function(instPkgs, instVers, packageVersionFile = "._packageVersionsAuto.txt") {
   inst <- data.frame(instPkgs, instVers = unlist(instVers), stringsAsFactors = FALSE)
   write.table(inst, file = packageVersionFile, row.names = FALSE)
@@ -133,3 +114,34 @@ basename2 <- function (x) {
     basename(x)
   }
 }
+
+#' A wrapper around \code{try} that retries on failure
+#'
+#' This is useful for functions that are "flaky", such as
+#' \code{curl}, which may fail for unknown reasons that do not
+#' persist.
+#' @param ... Passed to \code{try}
+#' @param sleep Passed to \code{Sys.sleep}, the default
+#'   delay in seconds bewteen repeated tries
+#' @param retries Numeric. The maximum number of retries.
+#' @export
+#' @details
+#' The same as \code{try}
+#'
+retry <- function(..., sleep = 0.5, retries = 5) {
+  failed <- 1
+  while(failed > 0  && failed < retries) {
+    downloadResults <- try(...)
+    if (is(downloadResults, "try-error")) {
+      failed <- failed + 1
+      print("retrying")
+      if (failed >= retries)
+        stop("Failed uploading to GoogleDrive")
+      Sys.sleep(sleep)
+    } else {
+      failed <- 0
+    }
+  }
+  downloadResults
+
+}
