@@ -71,6 +71,8 @@
 #'                         deleting objects. This, therefore, is most useful if the user is
 #'                         using unique values for \code{userTags}\cr
 #'   \code{useCloud} \tab Passed to \code{Cache}. Default \code{FALSE}.\cr
+#'   \code{useGDAL} \tab Passed to \code{useGDAL} in \code{projectInputs.Raster}.
+#'                   Default \code{TRUE}.\cr
 #'   \code{useMemoise} \tab \code{TRUE} \tab Used in \code{\link{Cache}}. If \code{TRUE},
 #'                   recovery of cached elements from the cacheRepo will use
 #'                   \code{memoise::memoise}. This means that the 3rd time running a function
@@ -91,7 +93,6 @@
 #'      and the time it took to digest them and also the time it took to run
 #'      the call and save the call to the cache repository or load the cached
 #'      copy from the repository. This may help diagnosing some problems that may occur.\cr
-#'
 #' }
 #'
 #' @section Advanced:
@@ -106,7 +107,7 @@
 #'                      NA values in their first MANY elements\cr
 #'   \code{useragent} \tab \code{"http://github.com/PredictiveEcology/reproducible"}
 #'           \tab User agent for downloads using this package.\cr
-#'    }
+#' }
 reproducibleOptions <- function() {
   list( # nolint
     reproducible.ask = TRUE,
@@ -123,6 +124,7 @@ reproducibleOptions <- function() {
     reproducible.showSimilar = FALSE,
     reproducible.useCache = TRUE, # override Cache function
     reproducible.useCloud = FALSE, #
+    reproducible.useGDAL = TRUE, #
     reproducible.useMemoise = TRUE, #memoise
     reproducible.useNewDigestAlgorithm = TRUE,
     reproducible.useragent = "http://github.com/PredictiveEcology/reproducible",
